@@ -38,7 +38,7 @@ import (
 	properties "github.com/arduino/go-properties-orderedmap"
 	"github.com/arduino/go-timeutils"
 	"github.com/sirupsen/logrus"
-	"go.bug.st/downloader/v2"
+	"go.bug.st/downloader/v3"
 	semver "go.bug.st/relaxed-semver"
 )
 
@@ -197,6 +197,11 @@ func (pm *PackageManager) NewExplorer() (explorer *Explorer, release func()) {
 	}, pm.packagesLock.RUnlock
 }
 
+// Destroy releases all resources held by the PackageManager.
+func (pm *PackageManager) Destroy() {
+	pm.discoveryManager.Clear()
+}
+
 // GetProfile returns the active profile for this package manager, or nil if no profile is selected.
 func (pme *Explorer) GetProfile() *sketch.Profile {
 	return pme.profile
